mp3togo version 0.5.2
/mp3togo/conf.py
blob:a7e25b1aa36864ab3e73970d8394c55939c06344 -> blob:730690d8bed946607269be0f2e1f223056c2a2fd
--- mp3togo/conf.py
+++ mp3togo/conf.py
@@ -137,6 +137,7 @@ class Options(options.Options):
self.bin['mpg321'] = False
self.bin['ogg123'] = False
self.bin['flac'] = False
+ self.bin['faad'] = False
self.bin['metaflac'] = False
self.bin['normalize-audio'] = False
self.bin['dcop'] = False
@@ -152,7 +153,7 @@ Description:
mp3 player or an mp3 CD. The files to convert can be
specified in a playlist file (m3u, pls and plain text are
supported) or given as arguments to the program. mp3togo
will go through the list and run mpg321, ogg123, flac and
lame to decode and reencode the files. The newly encoded
files will be written to the destination directory. The
software can retain as much of the subdirectory structure
@@ -238,7 +239,7 @@ def getfiletype(filename):
"""Return the format of an audio file"""
# Could use some more magic here
ft = os.path.splitext(filename)[1][1:]
- if ft not in ('mp3', 'ogg', 'flac', 'wav'):
+ if ft not in ('mp3', 'ogg', 'flac', 'wav', 'm4a'):
raise ErrorUnknownFileType
return ft
@@ -152,7 +153,7 @@ Description:
specified in a playlist file (m3u, pls and plain text are
supported) or given as arguments to the program. mp3togo
- will go through the list and run mpg321, ogg123, flac and
+ will go through the list and run mpg321, ogg123, flac, faad and
lame to decode and reencode the files. The newly encoded
files will be written to the destination directory. The